@@ -1,3 +1,4 @@
+import logging
 import os
 import shutil
 import sys
@@ -5,6 +6,8 @@ import time
 import traceback
 from argparse import ArgumentParser
 import lcbuilder.eleanor
+from lcbuilder.constants import USER_HOME_ELEANOR_CACHE
+
 sys.modules['eleanor'] = sys.modules['lcbuilder.eleanor']
 import eleanor
 from sherlockpipe.ois.OisManager import OisManager
@@ -17,7 +20,7 @@ class Updater:
     timestamps to remind when was the last time it updated and if called again, it could do nothing if it reads very
     recent operations.
     """
-    def __init__(self, cache_dir):
+    def __init__(self, cache_dir=os.path.expanduser('~') + "/"):
         self.cache_dir = cache_dir
 
     def update(self, clean, ois, force):
@@ -31,10 +34,8 @@ class Updater:
         ois_manager = OisManager(self.cache_dir)
         timestamp_ois_path = os.path.join(self.cache_dir, '.sherlockpipe/timestamp_ois.txt')
         timestamp_eleanor_path = os.path.join(self.cache_dir, '.sherlockpipe/timestamp_eleanor.txt')
-        timestamp_latte_path = os.path.join(self.cache_dir, '.sherlockpipe/timestamp_latte.txt')
         ois_timestamp = 0
         eleanor_timestamp = 0
-        latte_timestamp = 0
         force = force or clean
         if os.path.exists(timestamp_ois_path):
             with open(timestamp_ois_path, 'r+') as f:
@@ -42,20 +43,17 @@ class Updater:
         if os.path.exists(timestamp_eleanor_path):
             with open(timestamp_eleanor_path, 'r+') as f:
                 eleanor_timestamp = f.read()
-        if os.path.exists(timestamp_latte_path):
-            with open(timestamp_latte_path, 'r+') as f:
-                latte_timestamp = f.read()
         if force or time.time() - float(ois_timestamp) > 3600 * 24 * 7:
-            print("------------------ Reloading TOIs ------------------")
+            logging.info("------------------ Reloading TOIs ------------------")
             ois_manager.update_tic_csvs()
-            print("------------------ Reloading KOIs ------------------")
+            logging.info("------------------ Reloading KOIs ------------------")
             ois_manager.update_kic_csvs()
-            print("------------------ Reloading EPICs ------------------")
+            logging.info("------------------ Reloading EPICs ------------------")
             ois_manager.update_epic_csvs()
             with open(os.path.join(os.path.expanduser('~'), '.sherlockpipe/timestamp_ois.txt'), 'w+') as f:
                 f.write(str(time.time()))
         if force or time.time() - float(eleanor_timestamp) > 3600 * 24 * 7:
-            print("------------------ Reloading ELEANOR TESS FFI data ------------------")
+            logging.info("------------------ Reloading ELEANOR TESS FFI data ------------------")
             eleanorpath = os.path.join(self.cache_dir, '.eleanor')
             eleanormetadata = eleanorpath + "/metadata"
             if clean and os.path.exists(eleanorpath) and os.path.exists(eleanormetadata):
@@ -86,4 +84,4 @@ if __name__ == '__main__':
     ap.add_argument('--only_ois', dest='ois', action='store_true', help="Whether to only refresh objects of interest.")
     ap.add_argument('--force', dest='force', action='store_true', help="Whether to ignore update timestamps and do everything again.")
     args = ap.parse_args()
-    Updater().update(args.clean, args.ois, args.force)
+    Updater(USER_HOME_ELEANOR_CACHE).update(args.clean, args.ois, args.force)
